Struct cardinal_token_manager::accounts::AddInvalidatorCtx
source · [−]Expand description
Generated client accounts for AddInvalidatorCtx.
Fields
token_manager: Pubkeyissuer: PubkeyTrait Implementations
sourceimpl BorshSerialize for AddInvalidatorCtx where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for AddInvalidatorCtx where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for AddInvalidatorCtx
impl ToAccountMetas for AddInvalidatorCtx
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client. Read more