pub struct CreateTransferReceiptCtx {
pub token_manager: Pubkey,
pub transfer_authority: Pubkey,
pub transfer_receipt: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for CreateTransferReceiptCtx.
Fields
token_manager: Pubkeytransfer_receipt: Pubkeysystem_program: PubkeyTrait Implementations
sourceimpl BorshSerialize for CreateTransferReceiptCtx where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for CreateTransferReceiptCtx where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for CreateTransferReceiptCtx
impl ToAccountMetas for CreateTransferReceiptCtx
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client. Read more