Struct cardinal_token_manager::accounts::InitCtx
source · [−]pub struct InitCtx {
pub token_manager: Pubkey,
pub mint_counter: Pubkey,
pub mint: Pubkey,
pub issuer: Pubkey,
pub payer: Pubkey,
pub issuer_token_account: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for InitCtx.
Fields
token_manager: Pubkeymint_counter: Pubkeymint: Pubkeyissuer: Pubkeypayer: Pubkeyissuer_token_account: Pubkeysystem_program: PubkeyTrait Implementations
sourceimpl BorshSerialize for InitCtxwhere
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for InitCtxwhere
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for InitCtx
impl ToAccountMetas for InitCtx
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
A: Allocator,
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client. Read moreAuto Trait Implementations
impl RefUnwindSafe for InitCtx
impl Send for InitCtx
impl Sync for InitCtx
impl Unpin for InitCtx
impl UnwindSafe for InitCtx