Struct cardinal_token_manager::accounts::InvalidateCtx
source · [−]pub struct InvalidateCtx {
pub token_manager: Pubkey,
pub token_manager_token_account: Pubkey,
pub mint: Pubkey,
pub recipient_token_account: Pubkey,
pub invalidator: Pubkey,
pub collector: Pubkey,
pub token_program: Pubkey,
}Expand description
Generated client accounts for InvalidateCtx.
Fields
token_manager: Pubkeytoken_manager_token_account: Pubkeymint: Pubkeyrecipient_token_account: Pubkeyinvalidator: Pubkeycollector: PubkeyCHECK: This is not dangerous because we don’t read or write from this account
token_program: PubkeyTrait Implementations
sourceimpl BorshSerialize for InvalidateCtx where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for InvalidateCtx where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for InvalidateCtx
impl ToAccountMetas for InvalidateCtx
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client. Read more