Struct cardinal_token_manager::accounts::IssueCtx
source · [−]pub struct IssueCtx {
pub token_manager: Pubkey,
pub token_manager_token_account: Pubkey,
pub issuer: Pubkey,
pub issuer_token_account: Pubkey,
pub payer: Pubkey,
pub token_program: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for IssueCtx.
Fields
token_manager: Pubkeytoken_manager_token_account: Pubkeyissuer: Pubkeyissuer_token_account: Pubkeypayer: Pubkeytoken_program: Pubkeysystem_program: PubkeyTrait Implementations
sourceimpl BorshSerialize for IssueCtxwhere
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for IssueCtxwhere
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for IssueCtx
impl ToAccountMetas for IssueCtx
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
A: Allocator,
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client. Read moreAuto Trait Implementations
impl RefUnwindSafe for IssueCtx
impl Send for IssueCtx
impl Sync for IssueCtx
impl Unpin for IssueCtx
impl UnwindSafe for IssueCtx