Struct cardinal_token_manager::accounts::TransferCtx
source · [−]pub struct TransferCtx {
pub token_manager: Pubkey,
pub token_manager_token_account: Pubkey,
pub mint: Pubkey,
pub current_holder_token_account: Pubkey,
pub recipient: Pubkey,
pub recipient_token_account: Pubkey,
pub token_program: Pubkey,
}Expand description
Generated client accounts for TransferCtx.
Fields
token_manager: Pubkeytoken_manager_token_account: Pubkeymint: Pubkeycurrent_holder_token_account: Pubkeyrecipient: Pubkeyrecipient_token_account: Pubkeytoken_program: PubkeyTrait Implementations
sourceimpl BorshSerialize for TransferCtx where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for TransferCtx where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for TransferCtx
impl ToAccountMetas for TransferCtx
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client. Read more