Struct cardinal_token_manager::accounts::UninitCtx
source · [−]pub struct UninitCtx {
pub token_manager: Pubkey,
pub issuer: Pubkey,
pub issuer_token_account: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for UninitCtx.
Fields
token_manager: Pubkeyissuer: Pubkeyissuer_token_account: Pubkeysystem_program: PubkeyTrait Implementations
sourceimpl BorshSerialize for UninitCtx where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for UninitCtx where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for UninitCtx
impl ToAccountMetas for UninitCtx
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client. Read more