Struct cardinal_token_manager::accounts::UnissueCtx
source · [−]pub struct UnissueCtx {
pub token_manager: Pubkey,
pub token_manager_token_account: Pubkey,
pub issuer: Pubkey,
pub issuer_token_account: Pubkey,
pub token_program: Pubkey,
}Expand description
Generated client accounts for UnissueCtx.
Fields
token_manager: Pubkeytoken_manager_token_account: Pubkeyissuer: Pubkeyissuer_token_account: Pubkeytoken_program: PubkeyTrait Implementations
sourceimpl BorshSerialize for UnissueCtx where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for UnissueCtx where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for UnissueCtx
impl ToAccountMetas for UnissueCtx
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client. Read more