Struct cardinal_token_manager::state::ClaimReceipt
source · [−]Fields
mint_count: u64token_manager: Pubkeytarget: PubkeyTrait Implementations
sourceimpl AccountDeserialize for ClaimReceipt
impl AccountDeserialize for ClaimReceipt
sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a Mint account into a token
Account. Read more
sourceimpl AccountSerialize for ClaimReceipt
impl AccountSerialize for ClaimReceipt
sourceimpl BorshDeserialize for ClaimReceipt where
u64: BorshDeserialize,
Pubkey: BorshDeserialize,
Pubkey: BorshDeserialize,
impl BorshDeserialize for ClaimReceipt where
u64: BorshDeserialize,
Pubkey: BorshDeserialize,
Pubkey: BorshDeserialize,
sourceimpl BorshSerialize for ClaimReceipt where
u64: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for ClaimReceipt where
u64: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
sourceimpl Clone for ClaimReceipt
impl Clone for ClaimReceipt
sourcefn clone(&self) -> ClaimReceipt
fn clone(&self) -> ClaimReceipt
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Discriminator for ClaimReceipt
impl Discriminator for ClaimReceipt
fn discriminator() -> [u8; 8]