Struct cardinal_token_manager::state::MintCounter
source · [−]Fields
bump: u8mint: Pubkeycount: u64Trait Implementations
sourceimpl AccountDeserialize for MintCounter
impl AccountDeserialize for MintCounter
sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a Mint account into a token
Account. Read more
sourceimpl AccountSerialize for MintCounter
impl AccountSerialize for MintCounter
sourceimpl BorshDeserialize for MintCounter where
u8: BorshDeserialize,
Pubkey: BorshDeserialize,
u64: BorshDeserialize,
impl BorshDeserialize for MintCounter where
u8: BorshDeserialize,
Pubkey: BorshDeserialize,
u64: BorshDeserialize,
sourceimpl BorshSerialize for MintCounter where
u8: BorshSerialize,
Pubkey: BorshSerialize,
u64: BorshSerialize,
impl BorshSerialize for MintCounter where
u8: BorshSerialize,
Pubkey: BorshSerialize,
u64: BorshSerialize,
sourceimpl Clone for MintCounter
impl Clone for MintCounter
sourcefn clone(&self) -> MintCounter
fn clone(&self) -> MintCounter
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Discriminator for MintCounter
impl Discriminator for MintCounter
fn discriminator() -> [u8; 8]