Struct cardinal_token_manager::state::MintManager
source · [−]Fields
bump: u8initializer: Pubkeytoken_managers: u64Trait Implementations
sourceimpl AccountDeserialize for MintManager
impl AccountDeserialize for MintManager
sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account. Read moresourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed. Read more
sourceimpl AccountSerialize for MintManager
impl AccountSerialize for MintManager
sourceimpl BorshDeserialize for MintManagerwhere
u8: BorshDeserialize,
Pubkey: BorshDeserialize,
u64: BorshDeserialize,
impl BorshDeserialize for MintManagerwhere
u8: BorshDeserialize,
Pubkey: BorshDeserialize,
u64: BorshDeserialize,
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes. Read more
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
sourceimpl BorshSerialize for MintManagerwhere
u8: BorshSerialize,
Pubkey: BorshSerialize,
u64: BorshSerialize,
impl BorshSerialize for MintManagerwhere
u8: BorshSerialize,
Pubkey: BorshSerialize,
u64: BorshSerialize,
sourceimpl Clone for MintManager
impl Clone for MintManager
sourcefn clone(&self) -> MintManager
fn clone(&self) -> MintManager
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Discriminator for MintManager
impl Discriminator for MintManager
fn discriminator() -> [u8; 8]