#[repr(u8)]
pub enum InvalidationType {
Return,
Invalidate,
Release,
}Variants
Return
Upon invalidation it will be returned to the issuer
Invalidate
Upon invalidation it will remain marked as invalid
Release
Upon invalidation the token manager will be deleted and thus the tokens are released